ImapInput

Enum ImapInput 

pub enum ImapInput {
    Line(String),
    LiteralData(Vec<u8>),
}
One decoded IMAP-session frame.

Variants



Line(String)

A line-mode frame (everything up to the CRLF, exclusive). Returned for both client commands (A001 LOGIN …) and continuation requests (+ ready for literal). Non-UTF-8 bytes are replaced with U+FFFD (lossy conversion).



LiteralData(Vec<u8>)

A literal-mode frame: exactly N bytes as requested by the most recent ImapCodec::expect_literal call. The trailing CRLF that often follows a literal is consumed automatically when present.